==> core-0.0.32-sources.jar: de/quantummaid/injectmaid/Definition.java <==
/*
 * Copyright (c) 2020 Richard Hauswald - https://quantummaid.de/.
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package de.quantummaid.injectmaid;

import de.quantummaid.injectmaid.api.ReusePolicy;
import de.quantummaid.injectmaid.api.SingletonType;
import de.quantummaid.injectmaid.instantiator.Instantiator;
import de.quantummaid.reflectmaid.ResolvedType;
import lombok.AccessLevel;
import lombok.EqualsAndHashCode;
import lombok.RequiredArgsConstructor;
import lombok.ToString;

@ToString
@EqualsAndHashCode
@RequiredArgsConstructor(access = AccessLevel.PRIVATE)
public final class Definition {
    private final ResolvedType type;
    private final Scope scope;
    private final Instantiator instantiator;
    private final ReusePolicy reusePolicy;

    public static Definition definition(final ResolvedType type,
                                        final Scope scope,
                                        final Instantiator instantiator,
                                        final ReusePolicy reusePolicy) {
        return new Definition(type, scope, instantiator, reusePolicy);
    }

    public boolean isEagerSingleton(final SingletonType defaultSingletonType) {
        if (reusePolicy == ReusePolicy.SINGLETON) {
            return defaultSingletonType == SingletonType.EAGER;
        }
        return reusePolicy == ReusePolicy.EAGER_SINGLETON;
    }

    public ResolvedType type() {
        return type;
    }

    public Scope scope() {
        return scope;
    }

    public Instantiator instantiator() {
        return instantiator;
    }

    public boolean isSingleton() {
        return reusePolicy != ReusePolicy.PROTOTYPE;
    }

    public ReusePolicy reusePolicy() {
        return reusePolicy;
    }
}

==> core-0.0.48-sources.jar: de/quantummaid/injectmaid/Definition.java <==
/*
 * Copyright (c) 2020 Richard Hauswald - https://quantummaid.de/.
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package de.quantummaid.injectmaid;

import de.quantummaid.injectmaid.api.ReusePolicy;
import de.quantummaid.injectmaid.api.SingletonType;
import de.quantummaid.injectmaid.instantiator.Instantiator;
import de.quantummaid.reflectmaid.ResolvedType;
import lombok.AccessLevel;
import lombok.EqualsAndHashCode;
import lombok.RequiredArgsConstructor;
import lombok.ToString;

@ToString
@EqualsAndHashCode
@RequiredArgsConstructor(access = AccessLevel.PRIVATE)
public final class Definition {
    private final ResolvedType type;
    private final Scope scope;
    private final Instantiator instantiator;
    private final ReusePolicy reusePolicy;

    public static Definition definition(final ResolvedType type,
                                        final Scope scope,
                                        final Instantiator instantiator,
                                        final ReusePolicy reusePolicy) {
        return new Definition(type, scope, instantiator, reusePolicy);
    }

    public boolean isEagerSingleton(final SingletonType defaultSingletonType) {
        if (reusePolicy == ReusePolicy.DEFAULT_SINGLETON) {
            return defaultSingletonType == SingletonType.EAGER;
        }
        return reusePolicy == ReusePolicy.EAGER_SINGLETON;
    }

    public ResolvedType type() {
        return type;
    }

    public Scope scope() {
        return scope;
    }

    public Instantiator instantiator() {
        return instantiator;
    }

    public boolean isSingleton() {
        return reusePolicy != ReusePolicy.PROTOTYPE;
    }

    public ReusePolicy reusePolicy() {
        return reusePolicy;
    }
}
